@@ -5,7 +5,7 @@ use warnings;
 
 # ABSTRACT: Integrate reCAPTCHA into Dancer2 applications
 
-our $VERSION = '0.2'; # VERSION
+our $VERSION = '0.3'; # VERSION
 
 use Dancer2::Plugin;
 use Captcha::reCAPTCHA::V2;
@@ -50,7 +50,7 @@ Dancer2::Plugin::reCAPTCHA - Integrate reCAPTCHA into Dancer2 applications
 
 =head1 VERSION
 
-version 0.2
+version 0.3
 
 =head1 SYNOPSIS
 
@@ -84,8 +84,8 @@ Display it:
 
 Validate user input in a route handler:
 
-    my $response  = param('g-recaptcha-response');
-    my $result    = recaptcha_verify($response);
+    my $response = param('g-recaptcha-response');
+    my $result   = recaptcha_verify($response);
 
     if ($result->{success}) {
         # Good
@@ -160,14 +160,14 @@ Returns a reference to a hash containing two fields: C<success> and C<error_code
 
 Example: 
 
-    my $response  = param('g-recaptcha-response');
-    my $result    = recaptcha_verify($response);
+    my $response = param('g-recaptcha-response');
+    my $result   = recaptcha_verify($response);
 
     if ($result->{success}) {
         print "You are a human!";
     } 
     else {
-        print $result->{error_codes};
+        print $result->{error_codes}->[0];
     }
 
 =head1 SEE ALSO
